﻿using System.IO;
using System.Windows;

using CodeManager.Data;
using CodeManager.Service;
using CodeManager.ViewModel;
using CodeManager.Views;

using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;

namespace CodeManager
{
    public partial class App
    {
        private ServiceProvider ServiceProvider { get; set; }
        private IConfigurationRoot Configuration { get; set; }

        protected override void OnStartup(StartupEventArgs e)
        {
            base.OnStartup(e);

            var builder = new ConfigurationBuilder()
                .SetBasePath(Directory.GetCurrentDirectory())
                .AddJsonFile("appsettings.json", optional: false, reloadOnChange: true);

            Configuration = builder.Build();

            var serviceCollection = new ServiceCollection();
            ConfigurationServices(serviceCollection);

            ServiceProvider = serviceCollection.BuildServiceProvider();
            var mainView = ServiceProvider.GetRequiredService<MainWindow>();
            mainView.Show();

            base.OnStartup(e);
        }

        private void ConfigurationServices(IServiceCollection services)
        {
            services.AddTransient(typeof(MainWindow));

            services.AddScoped<ISnippetService, SnippetService>();

            services.AddDbContext<SnippetContext>(options => options.UseSqlServer(Configuration.GetConnectionString("SqlConnection")));
        }
    }
}
